==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/block/transaction/BlockTransactionReceipt.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.block.transaction;

import org.spongepowered.api.ResourceKey;
import org.spongepowered.api.Sponge;
import org.spongepowered.api.block.BlockSnapshot;
import org.spongepowered.api.data.persistence.DataContainer;
import org.spongepowered.api.data.persistence.DataSerializable;
import org.spongepowered.api.data.persistence.Queries;
import org.spongepowered.api.registry.RegistryTypes;

public final class BlockTransactionReceipt implements DataSerializable {

    private final BlockSnapshot originalBlock;
    private final BlockSnapshot finalBlock;
    private final Operation operation;

    public BlockTransactionReceipt(final BlockSnapshot originalBlock, final BlockSnapshot finalBlock, final Operation operation) {
        this.originalBlock = originalBlock;
        this.finalBlock = finalBlock;
        this.operation = operation;
    }

    public BlockSnapshot getOriginal() {
        return this.originalBlock;
    }

    public BlockSnapshot getFinal() {
        return this.finalBlock;
    }

    public Operation getOperation() {
        return this.operation;
    }

    @Override
    public int getContentVersion() {
        return 1;
    }

    @Override
    public DataContainer toContainer() {
        final ResourceKey resourceKey = Sponge.getGame().registries().registry(RegistryTypes.OPERATION).valueKey(this.operation);

        return DataContainer.createNew()
            .set(Queries.CONTENT_VERSION, this.getContentVersion())
            .set(Queries.ORIGINAL, this.originalBlock.toContainer())
            .set(Queries.FINAL_REPLACEMENT, this.finalBlock.toContainer())
            .set(Queries.BLOCK_OPERATION, resourceKey)
        ;
    }
}

==> spongeapi-8.0.0-20210324.005901-379-sources.jar: org/spongepowered/api/block/transaction/BlockTransactionReceipt.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.block.transaction;

import org.spongepowered.api.ResourceKey;
import org.spongepowered.api.Sponge;
import org.spongepowered.api.block.BlockSnapshot;
import org.spongepowered.api.data.persistence.DataContainer;
import org.spongepowered.api.data.persistence.DataSerializable;
import org.spongepowered.api.data.persistence.Queries;
import org.spongepowered.api.registry.RegistryTypes;

public final class BlockTransactionReceipt implements DataSerializable {

    private final BlockSnapshot originalBlock;
    private final BlockSnapshot finalBlock;
    private final Operation operation;

    public BlockTransactionReceipt(final BlockSnapshot originalBlock, final BlockSnapshot finalBlock, final Operation operation) {
        this.originalBlock = originalBlock;
        this.finalBlock = finalBlock;
        this.operation = operation;
    }

    public BlockSnapshot originalBlock() {
        return this.originalBlock;
    }

    public BlockSnapshot finalBlock() {
        return this.finalBlock;
    }

    public Operation operation() {
        return this.operation;
    }

    @Override
    public int contentVersion() {
        return 1;
    }

    @Override
    public DataContainer toContainer() {
        final ResourceKey resourceKey = Sponge.game().registries().registry(RegistryTypes.OPERATION).valueKey(this.operation);

        return DataContainer.createNew()
            .set(Queries.CONTENT_VERSION, this.contentVersion())
            .set(Queries.ORIGINAL, this.originalBlock.toContainer())
            .set(Queries.FINAL_REPLACEMENT, this.finalBlock.toContainer())
            .set(Queries.BLOCK_OPERATION, resourceKey)
        ;
    }
}
